/**
 * An interface used to define a writer used by trace to print (log).
 */
export interface TraceWriter {
    write(message: any, category: string, type?: number): void;
}
/**
 * An interface used to trace information about specific event.
 */
export interface TraceEventListener {
    filter: string;
    on(object: Object, name: string, data?: any): void;
}
/**
 * An interface used to for handling trace error
 */
export interface TraceErrorHandler {
    handlerError(error: Error): any;
}
export declare namespace Trace {
    /**
     * Enables the trace module.
     */
    function enable(): void;
    /**
     * Disables the trace module.
     */
    function disable(): void;
    /**
     * A function that returns whether the tracer is enabled and there is a point in writing messages.
     * Check this to avoid writing complex string templates.
     * Send error messages even if tracing is disabled.
     */
    function isEnabled(): boolean;
    /**
     * Adds a TraceWriter instance to the trace module.
     * @param writer The TraceWriter instance to add.
     */
    function addWriter(writer: TraceWriter): void;
    /**
     * Removes a TraceWriter instance from the trace module.
     * @param writer The TraceWriter instance to remove.
     */
    function removeWriter(writer: TraceWriter): void;
    /**
     * Clears all the writers from the trace module.
     */
    function clearWriters(): void;
    /**
     * Sets the categories the module will trace.
     * @param categories The comma-separated list of categories. If not specified all messages from all categories will be traced.
     */
    function setCategories(categories: string): void;
    /**
     * Adds categories to existing categories the module will trace.
     * @param categories The comma-separated list of categories. If not specified all messages from all categories will be traced.
     */
    function addCategories(categories: string): void;
    /**
     * Check if category is already set in trace module.
     * @param category The category to check.
     */
    function isCategorySet(category: string): boolean;
    /**
     * Writes a message using the available writers.
     * @param message The message to be written.
     * @param category The category of the message.
     * @param type Optional, the type of the message - info, warning, error.
     */
    function write(message: any, category: string, type?: number): void;
    /**
     * Notifies all the attached listeners for an event that has occurred in the sender object.
     * @param object The Object instance that raised the event.
     * @param name The name of the raised event.
     * @param data An optional parameter that passes the data associated with the event.
     */
    function notifyEvent(object: Object, name: string, data?: any): void;
    function addEventListener(listener: TraceEventListener): void;
    function removeEventListener(listener: TraceEventListener): void;
    namespace messageType {
        const log = 0;
        const info = 1;
        const warn = 2;
        const error = 3;
    }
    /**
     * all predefined categories.
     */
    namespace categories {
        const Accessibility = "Accessibility";
        const VisualTreeEvents = "VisualTreeEvents";
        const Layout = "Layout";
        const Style = "Style";
        const ViewHierarchy = "ViewHierarchy";
        const NativeLifecycle = "NativeLifecycle";
        const Debug = "Debug";
        const Navigation = "Navigation";
        const Test = "Test";
        const Binding = "Binding";
        const BindingError = "BindingError";
        const Error = "Error";
        const Animation = "Animation";
        const Transition = "Transition";
        const Livesync = "Livesync";
        const ModuleNameResolver = "ModuleNameResolver";
        const MediaQuery = "MediaQuery";
        const separator = ",";
        const All: string;
        function concat(...args: any): string;
    }
    class DefaultErrorHandler implements TraceErrorHandler {
        handlerError(error: any): void;
    }
    function getErrorHandler(): TraceErrorHandler;
    function setErrorHandler(handler: TraceErrorHandler): void;
    /**
     * Passes an error to the registered ErrorHandler
     * @param error The error to be handled.
     */
    function error(error: string | Error): void;
}
